@@ -125,13 +125,13 @@ class dyn_obj:
                 bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
 
 class dyn_vec:
-    def __init__(self, obj, name, scale, offset):
+    def __init__(self, obj, name, scale_mag, scale_off, offset):
         self.parent = obj
         self.name = name+"_vector"
         
         self.parent_rf = ref_frame(self.name+"_empty", self.parent)
 
-        self.filepath =  self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj'
+        self.filepath = self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj' #"C:/Users/vargh/Documents/GitHub/bpsci/bpsci/assets/objects/arrow.obj" #bpsci.__file__.replace("__init__.py", "")+'\\assets\\objects\\arrow.obj'
 
         vec = bpy.ops.import_scene.obj(filepath=self.filepath)
         vec = bpy.context.selected_objects[0]
@@ -141,8 +141,8 @@ class dyn_vec:
         vec.parent = self.parent_rf.ob
         vec.name = self.name
         
-        self.scale = scale
-        vec.scale = (1, scale, 1)
+        self.scale = scale_mag
+        vec.scale = (scale_mag, scale_off, scale_off)
         
     def animate(self, x, y, z, frames):
         max_x = 1
@@ -174,10 +174,10 @@ class dyn_vec:
                 
             mag_arrow = np.sqrt(cur_x**2 + cur_y**2 + cur_z**2)*self.scale
             
-            self.vec.scale = (mag_arrow, mag_arrow, mag_arrow)
+            self.parent_rf.ob.scale = (mag_arrow, 1, 1)
+                
             self.point_rf.ob.location = (cur_x, cur_y, cur_z)
             
             self.point_rf.ob.keyframe_insert(data_path='location', frame=cur_frame)
-            self.vec.keyframe_insert(data_path='scale', frame=cur_frame)
-
+            self.parent_rf.ob.keyframe_insert(data_path='scale', frame=cur_frame)
 
